/**
 * local vars.
 */
var car_maker;
var car_model;
var car_type;
var rotation_speed = 10000; // the speed in which the list is reloaded.

/**
 * handle mark select tag.
 * <br>-------------------------------------------------------------------------
 * - set model list.
 */
function filterModelList(){
    // display loading lightbox.
    var lb = document.getElementById('lightbox');
    lb.style.display = 'block';
    
    // get select box value.
    var maker = document.getElementById('maker');
    var body_select = document.getElementById('body');
    
    maker = maker.options[maker.selectedIndex].value;
    
    // send query request for model list.
    $.ajax({
        url: 'ajax/car_model_list.php',
        data: {maker_filter: maker},
        type: 'post',
        success: function(output){
            var res_array = output.split(',');
            
            // check if there are at least 1 result. if not it means that the
            // request failed.
            if( res_array.length < 1 ){
                // hide loading
                document.getElementById('loading').style.display = 'none';

                // display error icon.
                document.getElementById('erroricon').style.display = 'inline-block';
                
                return;
            }
            
            var model_select = document.getElementById('model');
            var option;
            
            // reset options.
            var options = model_select.getElementsByTagName('option');
            for( var i=options.length-1; i >= 1; i-- ){
                model_select.removeChild(options[i]);
            }
            
            // reset body type selector.
            var opt = body_select.getElementsByTagName('option');
            for( i=opt.length-1; i >= 1; i-- ){
                body_select.removeChild(opt[i]);
            }
            
            body_select.options.selectedIndex = 0;
            body_select.disabled = true;
            
            if( maker == 'all' ){
                lb.style.display = 'none';
                model_select.disabled = true;
                return;
            }
            
            // attach options to the model select tag.
            for( var i=0; i < res_array.length; i++ ){
                option = document.createElement('option');
                option.text = res_array[i];
                option.value = res_array[i];
                
                model_select.add(option,model_select.options[null]);
            }
            
            // set maker to local.
            car_maker = maker;
            
            // remove lightbox.
            lb.style.display = 'none';
            model_select.disabled = false;
        },
        error: function(e){
            // hide loading
            document.getElementById('loading').style.display = 'none';
            
            // display error icon.
            document.getElementById('erroricon').style.display = 'inline-block';
            
            console.log('Unable to load model list due an internal error.');
        }
    });
}

/**
 * handle model select tag.
 * <br>-------------------------------------------------------------------------
 * - set car type list.
 */
function filterCarTypeList(){
    // make sure maker is set.
    if( car_maker == undefined || car_maker.length < 2 ){
        return;
    }
    
    // display loading lightbox.
    var lb = document.getElementById('lightbox');
    lb.style.display = 'block';
    
    // get select box value.
    var model = document.getElementById('model');
    model = model.options[model.selectedIndex].value;
    
    // send query request for model list.
    $.ajax({
        url: 'ajax/car_type_list.php',
        data: {maker_filter: car_maker, model_filter: model},
        type: 'post',
        success: function(output){
            var res_array = output.split(',');
            
            // check if there are at least 1 result. if not it means that the
            // request failed.
            if( res_array.length < 1 ){
                // hide loading
                document.getElementById('loading').style.display = 'none';

                // display error icon.
                document.getElementById('erroricon').style.display = 'inline-block';
                
                return;
            }
            
            var body_select = document.getElementById('body');
            var option;
            
            // reset options.
            var options = body_select.getElementsByTagName('option');
            for( var i=options.length-1; i >= 1; i-- ){
                body_select.removeChild(options[i]);
            }
            
            if( model == 'all' ){
                lb.style.display = 'none';
                body_select.disabled = true;
                return;
            }
            
            // attach options to the model select tag.
            for( var i=0; i < res_array.length; i++ ){
                option = document.createElement('option');
                option.text = res_array[i];
                option.value = res_array[i];
                
                body_select.add(option,body_select.options[null]);
            }
            
            // set model to local.
            car_model = model;
            
            // remove lightbox.
            lb.style.display = 'none';
            body_select.disabled = false;
        },
        error: function(e){
            // hide loading
            document.getElementById('loading').style.display = 'none';
            
            // display error icon.
            document.getElementById('erroricon').style.display = 'inline-block';
            
            console.log('Unable to load type list due an internal error.');
        }
    });
}

/* tabs */
$(document).ready(function(){
    $('#tabs a:first').tab('show');
    
    $('#tabs a').click(function (e) {
        e.preventDefault();
        $(this).tab('show');
    })
});

/* validate email from subscription form */
function validateEmail(){
    var ret;
    var emailc = document.getElementById('subsc');    
    var email = emailc.value;
    var filter = /^([a-zA-Z0-9_\.\-])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/;
    
    if( email.length < 1 ){
        ret = false;
    }
    
    if( !filter.test(email) ){
        ret = false;
    }
    
    if( !ret ){
        emailc.style.border = '1px solid #C00';
        document.getElementById('subscbtn').className = 'btn btn-danger inputBtn';
    }
    
    return ret;
}

/* load latest added vehicles */
function loadFeaturedVehicles(cc,cs,bs){
    var wrap = document.getElementById('latest-wrapper');
    var ul = document.getElementById('list-wrapper');
        
    $.post(
        'ajax/load_home_latest_list.php',
        {
            current_code: cc,
            currency_symbol: cs,
            base: bs
        },
        function (data,status){
            var result = data.split('?');
            
            // if it fails to load, try to assign var again.
            if( wrap == undefined || ul == undefined ){
                wrap = document.getElementById('latest-wrapper');
                ul = document.getElementById('list-wrapper');
            }
            
            if( result[0] != 'ok' ){
                var p = '<p class="alert alert-error">Unable to load vehicle list. Please reload the page.</p>';
                wrap.innerHTML += p;
                return;
            }
            else {
                var res = result[1];
                var list;
                var li;
                var featurl;
                
                res = res.split('[]');
                
                // remove latest car list if no car is available.
                if( res.length < 1 || res[0].length < 1 ){
                    // if no car is available, remove latest car vehicle tab.
                    var wrap = document.getElementById('inner-content');
                    var latest = document.getElementById('latest-wrapper');
                    
                    if( wrap != undefined && latest != undefined ){
                        wrap.removeChild(latest);
                        console.log('removed');
                        return;
                    }
                }
                                
                for( var i=0; i < res.length; i++ ){
                    list = res[i].split(';');
                    
                    ( list[6] == 1 ? featurl = 'image/featured.png' : featurl = 'image/transparent_pixel.png' );
                    
                    if( list[0] != undefined && list[1] != undefined && list[2] != undefined && list[3] != undefined ){
                        li  = '<li class="span3" style="position:relative;margin-left:30px;">';
                        li += '<img src="'+featurl+'" alt="Featured" class="carFeatImg"/>';
                        li += '<a href="'+list[1].replace(' ','')+'-'+list[2].replace(' ','')+'-'+list[4].replace(' ','')+'/car-detail/?cid='+list[0]+'" class="thumbnail">';
                        li += '<img src="'+list[5]+'" alt="'+list[1]+' '+list[2]+'"/>';
                        li += '</a>';
                        li += '<span style="font-weight:bold;font-size:12px;text-align:center;display:block;margin-bottom:5px;">'+list[1]+' '+list[2]+' '+list[4]+'</span>';
                        li += '<div>';
                        li += '<span style="font-weight:bold;font-size:14px;text-align:center;display:block;color:green;float:left;padding-top:5px;"><?php echo CURRENCY_SYMBOL;?>'+list[3]+'</span>';
                        li += '<a href="'+list[1].replace(' ','')+'-'+list[2].replace(' ','')+'-'+list[4].replace(' ','')+'/car-detail/?cid='+list[0]+'" class="btn btn-small" style="float:right;"><i class="icon-road" style="margin-right:5px;"></i>More details</a>';
                        li += '</div>';
                        li += '<div class="clearfix"></div>';
                        li += '</li>';
                        
                        ul.innerHTML += li;
                        
                        var loader = document.getElementById('loadListLoader');
                        if( loader != undefined && wrap != undefined ){
                            wrap.removeChild(loader);
                        }
                    } 
                }
                
                setTimeout(function(){
                    if( ul == undefined ){
                        return;
                    }
                    
                    $(ul).fadeOut(500, function(){
                        ul.innerHTML = '';
                        loadFeaturedVehicles(cc, cs, bs);
                        $(ul).fadeIn(500);
                    });
                    
                    
                }, rotation_speed);
            }
            
        }
    );
}